@@ -3,7 +3,8 @@
 #' @param keys (numeric) GBIF keys, a vector.
 #' @param by (character) One of georeferenced, basisOfRecord, country, or
 #' publishingCountry.
-#' @param countries (numeric) Number of countries to facet on, or a vector of country names
+#' @param countries (numeric) Number of countries to facet on, or a vector of
+#' country names
 #' @param removezeros (logical) Default is FALSE
 #' @export
 #' @examples \dontrun{
@@ -13,10 +14,12 @@
 #' count_facet(by='country', countries='AR', removezeros = TRUE)
 #'
 #' spplist <- c('Geothlypis trichas','Tiaris olivacea','Pterodroma axillaris',
-#'              'Calidris ferruginea','Pterodroma macroptera','Gallirallus australis',
+#'              'Calidris ferruginea','Pterodroma macroptera',
+#'              'Gallirallus australis',
 #'              'Falco cenchroides','Telespiza cantans','Oreomystis bairdi',
 #'              'Cistothorus palustris')
-#' keys <- sapply(spplist, function(x) name_backbone(x, rank="species")$usageKey)
+#' keys <- sapply(spplist,
+#'   function(x) name_backbone(x, rank="species")$usageKey)
 #' count_facet(keys, by='country', countries=3, removezeros = TRUE)
 #' count_facet(keys, by='country', countries=3, removezeros = FALSE)
 #' count_facet(by='country', countries=20, removezeros = TRUE)
@@ -38,7 +41,8 @@
 #' count_facet(by="basisOfRecord")
 #' }
 
-count_facet <- function(keys = NULL, by = 'country', countries = 10, removezeros = FALSE) {
+count_facet <- function(keys = NULL, by = 'country', countries = 10,
+                        removezeros = FALSE) {
 
   # can't do both keys and basisofrecord
   if (!is.null(keys) && by == 'basisOfRecord') {
@@ -78,7 +82,7 @@ count_facet <- function(keys = NULL, by = 'country', countries = 10, removezeros
   }
 
   # remove NAs (which were caused by errors in country names)
-  df <- na.omit(df)
+  df <- stats::na.omit(df)
 
   if (removezeros) {
     df[!df$V1 == 0, ]
