@@ -5,13 +5,15 @@
 #' @template identifierargs
 #' @export
 #'
-#' @param data The type of data to get. One or more of: 'contact', 'endpoint', 'dataset',
-#' 'comment', 'deleted', 'nonPublishing', or the special 'all'. Default: \code{'all'}
+#' @param data The type of data to get. One or more of: 'contact', 'endpoint',
+#' 'dataset', 'comment', 'deleted', 'nonPublishing', or the special 'all'.
+#' Default: `'all'`
 #' @param uuid UUID of the data node provider. This must be specified if data
 #' is anything other than 'all'.
-#' @param query Query nodes. Only used when \code{data='all'}. Ignored otherwise.
+#' @param query Query nodes. Only used when `data='all'`. Ignored
+#' otherwise.
 #'
-#' @references \url{http://www.gbif.org/developer/registry#installations}
+#' @references <http://www.gbif.org/developer/registry#installations>
 #'
 #' @examples \dontrun{
 #' installations(limit=5)
@@ -25,19 +27,22 @@
 #' installations(data=c('deleted','nonPublishing'), limit=2)
 #' installations(identifierType='DOI', limit=2)
 #'
-#' # Pass on options to httr
-#' library('httr')
-#' res <- installations(data='deleted', config=progress())
+#' # Pass on curl options
+#' installations(data='deleted', curlopts = list(verbose=TRUE))
 #' }
 
-installations <- function(data = 'all', uuid = NULL, query = NULL, identifier=NULL,
-                          identifierType=NULL, limit=100, start=NULL, ...)
-{
-  args <- rgbif_compact(list(q = query, limit=as.integer(limit), offset=start))
+installations <- function(data = 'all', uuid = NULL, query = NULL,
+                          identifier=NULL, identifierType=NULL, limit=100,
+                          start=NULL, curlopts = list()) {
 
-  data <- match.arg(data, choices = c('all', 'contact', 'endpoint', 'dataset',
-                                    'identifier', 'tag', 'machineTag', 'comment',
-                                    'deleted', 'nonPublishing'), several.ok = TRUE)
+  args <- rgbif_compact(list(q = query, limit = as.integer(limit),
+                             offset = start))
+
+  data <- match.arg(data,
+                    choices = c('all', 'contact', 'endpoint', 'dataset',
+                                'identifier', 'tag', 'machineTag', 'comment',
+                                'deleted', 'nonPublishing'),
+                    several.ok = TRUE)
 
   # Define function to get data
   getdata <- function(x){
@@ -58,7 +63,7 @@ installations <- function(data = 'all', uuid = NULL, query = NULL, identifier=NU
         sprintf('%s/installation/%s/%s', gbif_base(), uuid, x)
       }
     }
-    res <- gbif_GET(url, args, TRUE, ...)
+    res <- gbif_GET(url, args, TRUE, curlopts)
     structure(list(meta = get_meta(res), data = parse_results(res, uuid)))
   }
 
