@@ -13,15 +13,30 @@
 #' @param type (charcter) One of equals (=), and (&), or (|), lessThan (<),
 #' lessThanOrEquals (<=), greaterThan (>), greaterThanOrEquals (>=), in,
 #' within, not (!), like
-#' @param user (character) User name within GBIF's website. Required. Set in
-#' your `.Rprofile` file with the option `gbif_user`
-#' @param pwd (character) User password within GBIF's website. Required. Set
-#' in your `.Rprofile` file with the option `gbif_pwd`
+#' @param user (character) User name within GBIF's website. Required. See
+#' Details.
+#' @param pwd (character) User password within GBIF's website. Required. See
+#' Details.
 #' @param email (character) Email address to recieve download notice done
-#' email. Required. Set in your `.Rprofile` file with the option
-#' `gbif_email`
+#' email. Required. See Details.
 #' @template occ
 #'
+#' @section Authentication:
+#' For `user`, `pwd`, and `email` parameters, you can set them in one of
+#' three ways:
+#'
+#' - Set them in your `.Rprofile` file with the names `gbif_user`,
+#' `gbif_pwd`, and `gbif_email`
+#' - Set them in your `.Renviron`/`.bash_profile` (or similar) file with the
+#' names `GBIF_USER`, `GBIF_PWD`, and `GBIF_EMAIL`
+#' - Simply pass strings to each of the parameters in the function
+#' call
+#'
+#' We strongly recommend the second option - storing your details as
+#' environment variables as it's the most widely used way to store secrets.
+#'
+#' See `?Startup` for help.
+#'
 #' @details Argument passed have to be passed as character (e.g.,
 #' 'country = US'), with a space between key ('country'), operator ('='),
 #' and value ('US'). See the `type` parameter for possible options for
@@ -79,6 +94,11 @@
 #'  \item recordedBy = 'RECORDED_BY'
 #' }
 #'
+#' @section Query length:
+#' GBIF has a limit of 12,000 characters for a download query. This means
+#' that you can have a pretty long query, but at some point it may lead to an
+#' error on GBIF's side and you'll have to split your query into a few.
+#'
 #' @references See the API docs
 #' <http://www.gbif.org/developer/occurrence#download> for more info,
 #' and the predicates docs
@@ -145,11 +165,13 @@
 #' # res <- occ_download(body = query, curlopts = list(verbose = TRUE))
 #' }
 
-occ_download <- function(..., body = NULL,
-   type = "and", user = getOption("gbif_user"), pwd = getOption("gbif_pwd"),
-   email = getOption("gbif_email"), curlopts = list()) {
+occ_download <- function(..., body = NULL, type = "and", user = NULL,
+  pwd = NULL, email = NULL, curlopts = list()) {
 
   url <- paste0(gbif_base(), '/occurrence/download/request')
+  user <- check_user(user)
+  pwd <- check_pwd(pwd)
+  email <- check_email(email)
   stopifnot(!is.null(user), !is.null(email))
   if (!is.null(body)) {
     req <- body
@@ -160,6 +182,21 @@ occ_download <- function(..., body = NULL,
   structure(out, class = "occ_download", user = user, email = email)
 }
 
+check_user <- function(x) {
+  z <- if (is.null(x)) Sys.getenv("GBIF_USER", "") else x
+  if (z == "") getOption("gbif_user", stop("supply a username")) else z
+}
+
+check_pwd <- function(x) {
+  z <- if (is.null(x)) Sys.getenv("GBIF_PWD", "") else x
+  if (z == "") getOption("gbif_pwd", stop("supply a password")) else z
+}
+
+check_email <- function(x) {
+  z <- if (is.null(x)) Sys.getenv("GBIF_EMAIL", "") else x
+  if (z == "") getOption("gbif_email", stop("supply an email address")) else z
+}
+
 check_inputs <- function(x) {
   if (is.character(x)) {
     # replace newlines
